import subprocess

from time import sleep
from pibot.nano import Nano
from pibot.lcd import LCD


def startup():
    lcd = LCD(fontsize=16)

    # show TU-Chemnitz logo on screen
    lcd.view_image("/home/pi/.resources/tu.pgm", 1)

    sleep(2)
    # show TU-Chemnitz text on screen
    lcd.view_image("/home/pi/.resources/tutext.pgm", 1)

    sleep(2)
    # show Roboschool logo on screen
    lcd.view_image("/home/pi/.resources/roboschool.pgm", 1)

    sleep(2)
    # show PiBot logo on screen
    lcd.view_image("/home/pi/.resources/pibot.pgm", 1)

    # getting IP
    cmd = "hostname -I | cut -d\' \' -f1"
    ip = (subprocess.check_output(cmd, shell=True)).decode("utf-8")

    # getting voltage
    nano = Nano()
    voltage = nano.get_battery_voltage()

    text = "IP: " + str(ip), "Battery: {} mV".format(voltage)
    lcd.print(text)
    sleep(2)



import RPi.GPIO as GPIO
from os import popen
from time import sleep
from pibot.lcd import LCD

POWER_OFF_PIN = 21


def background():
    GPIO.setmode(GPIO.BCM)
    GPIO.setup(POWER_OFF_PIN, GPIO.IN, GPIO.PUD_UP)

    lcd = LCD(fontsize=20)
    while 1:
        if not GPIO.input(POWER_OFF_PIN):
            time_till_shutoff = 5
            while not GPIO.input(POWER_OFF_PIN):
                message = ["  Poweroff in", "           " + str(time_till_shutoff)]
                lcd.print(message)
                time_till_shutoff = time_till_shutoff - 1
                sleep(1)
                if time_till_shutoff <= 0:
                    message = ["  Shutdown...", " "]
                    lcd.print(message)
                    sleep(1)
                    popen("sudo poweroff")
                    break
            lcd.clear()
        sleep(0.5)
